.. :changelog:

History
-------

0.1.3 (2015-09-27)
---------------------

* First release on PyPI.

0.1.4 (2015-10-15)

* Updated requests library

0.2.0 (2016-01-23)

* Added an api to disconnect from quickbooks

0.2.1 (2016-01-23)

* Making Resource name case insensitive

0.2.2 (2016-02-19)

* Bugfix in parsing query response when the response is empty
